@@ -1,9 +1,12 @@
 package Log::Abstraction;
 
+# TODO: add a minimum logging level
+
 use strict;
 use warnings;
 use Carp;	# Import Carp for warnings
 use Config::Abstraction;
+use Log::Log4perl;
 use Params::Get 0.04;	# Import Params::Get for parameter handling
 use Sys::Syslog;	# Import Sys::Syslog for syslog support
 use Scalar::Util 'blessed';	# Import Scalar::Util for object reference checking
@@ -14,11 +17,11 @@ Log::Abstraction - Logging Abstraction Layer
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 =head1 SYNOPSIS
 
@@ -67,7 +70,10 @@ For example:
 
 It doesn't work on Windows because of the case-insensitive nature of that system.
 
-=item * C<logger> - A logger can be a code reference, an array reference, a file path, or an object.
+=item * C<logger>
+
+A logger can be a code reference, an array reference, a file path, or an object.
+Defaults to L<Log::Log4perl>
 
 =item * C<syslog> - A hash reference for syslog configuration.
 
@@ -145,6 +151,13 @@ sub new {
 		# croak(__PACKAGE__, ' syslog needs to know the script name');
 	}
 
+	if(!defined($args{logger})) {
+		# Default to Log4perl
+		# FIXME: add default minimum logging level
+		Log::Log4perl->easy_init($args{verbose} ? $Log::Log4perl::DEBUG : $Log::Log4perl::ERROR);
+		$args{'logger'} = Log::Log4perl->get_logger();
+	}
+
 	my $self = {
 		messages => [],  # Initialize messages array
 		%args,
@@ -191,8 +204,9 @@ sub _log {
 				print $fout uc($level), ': ', blessed($self) || __PACKAGE__, ' ', (caller(1))[1], (caller(1))[2], ' ', join('', @messages), "\n";
 				close $fout;
 			}
-		} else {
+		} elsif($logger->can($level)) {
 			# If logger is an object, call the appropriate method on the object
+			# The test is because Log::Log4perl doesn't understand notice()
 			$logger->$level(@messages);
 		}
 	}
